==> org-lsst-ccs-messaging-jms-1.5.1-sources.jar: org/lsst/ccs/bus/jms/JMSBusMessagingLayer.java <==
package org.lsst.ccs.bus.jms;

//import org.apache.log4j.Logger;

import java.io.IOException;
import org.lsst.ccs.bus.Bus;
import org.lsst.ccs.bus.BusMembershipListener;
import org.lsst.ccs.bus.BusMessageForwarder;
import org.lsst.ccs.bus.BusMessagingLayer;
import org.lsst.ccs.bus.BusPayload;



/**
 */
public class JMSBusMessagingLayer implements BusMessagingLayer {

    @Override
    public void close() throws IOException {
        throw new UnsupportedOperationException("Not supported yet.");
    }

    @Override
    public void addMessageListener(String agentName, BusMessageForwarder forwarder, Bus... buses) {
        throw new UnsupportedOperationException("Not supported yet.");
    }

    @Override
    public void closeFor(String agentName, Bus... buses) {
        throw new UnsupportedOperationException("Not supported yet.");
    }

    @Override
    public void setMembershipListener(BusMembershipListener listener, Bus... buses) {
        throw new UnsupportedOperationException("Not supported yet.");
    }

    @Override
    public <T extends BusPayload> void sendMessage(String senderAgent, Bus<T> bus, T message, String... destinations) throws IOException {
        throw new UnsupportedOperationException("Not supported yet.");
    }

    @Override
    public void removeMessageListener(String agentName, BusMessageForwarder forwarder, Bus... buses) {
        throw new UnsupportedOperationException("Not supported yet.");
    }

    @Override
    public void register(String agentName, Bus... buses) throws IOException {
        throw new UnsupportedOperationException("Not supported yet.");
    }
    
    
}

==> org-lsst-ccs-messaging-jms-1.5.4-sources.jar: org/lsst/ccs/bus/jms/JMSBusMessagingLayer.java <==
package org.lsst.ccs.bus.jms;

//import org.apache.log4j.Logger;

import org.lsst.ccs.bus.*;

import java.io.IOException;
import java.util.Collections;
import java.util.List;



/**
 */
public class JMSBusMessagingLayer implements BusMessagingLayer {

    @Override
    public void close() throws IOException {
        throw new UnsupportedOperationException("Not supported yet.");
    }

    @Override
    public void addMessageListener(String agentName, BusMessageForwarder forwarder, Bus... buses) {
        throw new UnsupportedOperationException("Not supported yet.");
    }

    @Override
    public void closeFor(String agentName, Bus... buses) {
        throw new UnsupportedOperationException("Not supported yet.");
    }

    @Override
    public void setMembershipListener(BusMembershipListener listener, Bus... buses) {
        throw new UnsupportedOperationException("Not supported yet.");
    }

    @Override
    public List<String> getConnectedNames(Bus bus) {
        return Collections.EMPTY_LIST;
    }

    @Override
    public <T extends BusPayload> void sendMessage(String senderAgent, Bus<T> bus, T message, String... destinations) throws IOException {
        throw new UnsupportedOperationException("Not supported yet.");
    }

    @Override
    public void removeMessageListener(String agentName, BusMessageForwarder forwarder, Bus... buses) {
        throw new UnsupportedOperationException("Not supported yet.");
    }

    @Override
    public void register(String agentName, Bus... buses) throws IOException {
        throw new UnsupportedOperationException("Not supported yet.");
    }
    
    
}
